################################################################################
#             Does heat cause homicides? A meta-analysis               #
#                                Vojtěch Mišák                                   #
################################################################################
# Loading
#####################
#      Packages     #
##################### 

library(tidyverse)
library(ggplot2) 
library(readxl)
library(DescTools)
library(ivreg)
library(metafor)
library(clubSandwich)
library(puniform)
library(BMS)
library(foreign)
library(xtable)
library(LowRankQP)
library(clusterSEs)
library(metafor)
library(caret)
require(gridExtra)


setwd("~/")

raw_data <- read.csv("estimates.csv")
raw_data <- raw_data[raw_data$POP_VAR == 0,]
raw_data <- raw_data[raw_data$`IDStudy` != 18,]


# Fahrenheit to Celsius
# raw_data$`T` = ifelse(raw_data$Farnheit  == 1, raw_data$`T`/1.8, raw_data$`T`)
# raw_data$`SE` = ifelse(raw_data$Farnheit  == 1, raw_data$`SE`/1.8, raw_data$`SE`)

# write.csv(raw_data,"Desktop/metaanalyza/homicide_weather_meta/estimates.xlsx", row.names = FALSE)




raw_data$t_statistics<- ifelse(raw_data$SE == 0 | is.na(raw_data$SE) ,NA,raw_data$T/raw_data$SE)



# testovani pro Windsorizaci

## Testing statistical difference  for winsorization ##

ef<- cbind.data.frame(raw_data$`T`,"a")
colnames(ef)<-c("T","group")
ef_0.05<-Winsorize(raw_data$`T`, probs = c(0.05, 0.95))
ef_0.05<- cbind.data.frame(ef_0.05,"b")
colnames(ef_0.05)<-c("T","group")
ef_fin<- rbind.data.frame(ef,ef_0.05)
t.test(`T`~group,ef_fin) 


se<-raw_data$SE
se<- cbind.data.frame(raw_data$SE,"a")
colnames(se)<-c("se","group")
se_0.05<-Winsorize(raw_data$SE, probs = c(0.05, 0.95), na.rm = TRUE)
se_0.05<- cbind.data.frame(se_0.05,"b")
colnames(se_0.05)<-c("se","group")
se_fin<- rbind.data.frame(se,se_0.05)
t.test(se~group,se_fin) 

# no need to Windsorize



##  Effect boxplot  full ##
ggplot(raw_data, aes(x=reorder(author, `T`), y=`T`)) + 
  geom_boxplot(color  = "deepskyblue4", fill = "deepskyblue4") +
  coord_flip() + theme_minimal() +
  geom_hline(yintercept = mean(raw_data$T), color='red')+
  geom_hline(yintercept =0, color='deepskyblue4')+
  theme(axis.title.y=element_blank(),axis.title.x=element_blank(), axis.text=element_text(size=14))



ggplot(raw_data, aes(x=reorder(author, published_year), y=`T`)) + 
  geom_boxplot(color  = "deepskyblue4", fill = "deepskyblue4") +
  coord_flip() + theme_minimal() +
  geom_hline(yintercept = mean(raw_data$T), color='red')+
  geom_hline(yintercept =0, color='deepskyblue4')+
  theme(axis.title.y=element_blank(),axis.title.x=element_blank(), axis.text=element_text(size=14))


##  Effect distribution  ##

ggplot(raw_data,aes(x=T)) +
  geom_histogram(aes(y=..density..),color  = "deepskyblue4", fill = "deepskyblue4",breaks=c(seq(-0.05, 0.2, by=0.005)))+
  theme_minimal() +
  geom_vline(xintercept =0, color='red')+
  theme(text = element_text(size=15)) + 
  xlab("Effect") + 
  ylab("Count") 




######################
#  Publication bias  #
######################
#  Linear methods    #
######################
##   Simple Funnel plot (Egger et al., 1997)   ##

res1 <- rma(`T`,sei = SE,data=subset(raw_data,1/raw_data$SE<1200),method="FE")


funnel(res1, yaxis="seinv",xlab = "Estimated effect",ylab = "1/SE",digits=c(2,0),back = "white",shade="lightblue",col="darkblue",
      )



# OLS
ols_fat<-lm(`T`~SE,raw_data)
ols_pub<-coef_test(ols_fat, vcov = "CR2",cluster = raw_data$author,test="naive-t")
ols_pub


# aby nebyly zeros
raw_data = raw_data[, c("T", "SE", "author", "Pocet.odhadu")]
raw_data[raw_data==0] <- NA
raw_data<-raw_data[complete.cases(raw_data),]


#Fixed effects
fe_fat <- rma(`T`,sei = SE, mods= ~ SE,data=raw_data,method="FE")
fe_fat_rob<-robust(fe_fat,cluster = c(raw_data$author))
fe_fat_rob


#Precision_weights
prec_fat<-lm(`T`~SE,raw_data,weights = 1/SE)
prec_pub<-coef_test(prec_fat, vcov = "CR2",cluster = raw_data$author,test="naive-t")
prec_pub

#Study_weights
stud_fat<-lm(`T`~SE,raw_data,weights = 1/`Pocet.odhadu`)
stud_pub<-coef_test(stud_fat, vcov = "CR2",cluster = raw_data$author,test="naive-t")
stud_pub


raw_data <- read.csv("/home/vojta/Desktop/PAPERY/homicide_weather_meta/estimates.csv")


# By citation
raw_data$citations <- ifelse((is.na(raw_data$citations) | raw_data$citations == 0),1,raw_data$citations)
cited_fat<-lm(`T`~SE, raw_data, weights = citations)
cited_pub<-coef_test(cited_fat, vcov = "CR2",cluster = raw_data$author)
cited_pub



##############################
########non-linear methods####



######################
# Non-linear methods #
######################


#Stanley 2010 - Top10 - weighted by study
se_sort<-sort(raw_data$SE,decreasing = TRUE)
top_10_q<-quantile(se_sort,prob=0.9)
data_top10<-subset(raw_data, raw_data$SE>top_10_q)
top10 <- rma(T,sei = SE,data=data_top10,method="FE") #same

top10


##   WAAP   ##
#WAAP # Stan
#ley, T. D., Doucouliagos, H., & Ioannidis, J. P. A. (2017). Finding the power to reduce publication bias. 
#Statistics in Medicine, 54(3), 30-19. http://doi.org/10.1002/sim.7228
# only select studies that are adequatly powered (Stanley uses a two-sided test)


raw_data$t_statistics<- ifelse(raw_data$SE == 0 | is.na(raw_data$SE) ,NA,raw_data$T/raw_data$SE)




no_nadata <- raw_data[is.na(raw_data$t_statistics) == F,]
WLS<-lm(no_nadata$t_statistics~0+I(1/no_nadata$SE))
WLS$coefficients
powered <- abs(WLS$coefficients) >= no_nadata$SE
kAdequate <- sum(powered,na.rm=T)
data_restr<-no_nadata[powered,]
waap<-lm(t_statistics~0+I(1/SE),data=data_restr)
summary(waap)


#The Vevea and Hedges (1995) 
rmauni<-rma.uni(yi=raw_data$T,sei=raw_data$SE,method="HE")
rmauni




#BAYESIAN MODEL AVERAGING


raw_data <- read.csv("estimates.csv")


library(MASS)
library(BMA)
library(BMS)


df <- raw_data[,colSums(is.na(raw_data))<nrow(raw_data)]

df$citations <- (df$citations) / (2022 - df$published_year + 1)

homicides-bma <- df[,c( "T","SE", "MAX", "RAIN", "AVGT.2", "Poisson", "USA", "ANNUAL", "MONTHLY", "reviewed_journal" ,"citations", "ASIA", "Samplesize", "published_year", "OLS"  )]



homicides-bma <- homicides-bma[complete.cases(homicides-bma), ]


# prejmenujeme columns
names(homicides-bma)[names(homicides-bma) == "AVGT.2"] <- "TEMPERATURE^2"
names(homicides-bma)[names(homicides-bma) == "Poisson"] <- "POISSON"
names(homicides-bma)[names(homicides-bma) == "MAX"] <- "MAX TEMPERATURE"
names(homicides-bma)[names(homicides-bma) == "reviewed_journal"] <- "REVIEWED JOURNAL"
names(homicides-bma)[names(homicides-bma) == "citations"] <- "CITATIONS / (2022 - PUBLISHED YEAR + 1)"
names(homicides-bma)[names(homicides-bma) == "Samplesize"] <- "SAMPLE SIZE"
names(homicides-bma)[names(homicides-bma) == "published_year"] <- "PUBLISHED YEAR"



sapply(homicides-bma, class)


homicides = bms(homicides-bma, burn=1e5,iter=3e5, g="UIP", mprior="uniform", nmodel=50000, mcmc="bd", user.int=FALSE)


coef(homicides, order.by.pip = T, exact=T, include.constant=T)


image(homicides, yprop2pip=FALSE, order.by.pip=TRUE, do.par=TRUE, do.grid=TRUE, do.axis=TRUE, cex.axis = 0.7)
summary(homicides)
plot(homicides)













